/*	Windowed Terminal Emulator
 *	By Erin M. Monaco
 *
 *	Copyright 1994 DataBasement Software
 *	All Rights Reserved
 *
 *	OBJECTIVE:
 *	Provide a library of windowed terminal emulator routines suitable
 *	for displaying/controling a VT-52 type screen within the bounds
 *	of a given window.
 *
 */

#include "W_VT52.H"

/************************************************************************/
/*	w_escf()
 *
 *	Called after initialized. This function allows access to the VT_52
 *	esc+key sequences.  W_VT52.H provides definitions for each of the
 *	available esc functions.
 *
 *	I decided to use a function to pass esc codes for the simple fact
 *	that v_gtext can print out almost ANY character... and this could be
 *	very desirable in the case of certain types of editors, etc.  This
 *	way you can print out anything thats printable without worrying that
 *	it may inadvertantly screw up your display.  Only certain control
 *	codes are acted on such as LF, & CR.
 *
 */

int w_escf
(
	int windh,						/* windows handle */
	int com,							/* terminals esc command */
	short *row,						/* row number */
	short *col						/* column number */
)

{

	int index = 0;				/* index value */
	short srow, scol;

	short *ptw, *pth, *prows, *pcols, *pcrow;


	/* find correct WTES structure or signal error */
	while(wtes[index].windh != windh)
	{

		/* inc index */
		index++;

		/* test */
		if(index > WTESL)
			return(R_ERR);	/* not found, signal error */

	}	/* end while looking for correct WTES struct */	

	/* set up pointers to everything */
	ptw = &wtes[index].vt.tw;
	pth = &wtes[index].vt.th;
	prows = &wtes[index].vt.rows;
	pcols = &wtes[index].vt.cols;
	pcrow = &wtes[index].vt.crow;

	/* act on specific command */
	switch(com)
	{

		case ESC_A:
		{

			/* pass through to wte_pcur() for cursor movement */
			return(w_pcur(&wtes[index], ESC_A));

			break;

		}	/* end of case ESC_A */

		case ESC_B:
		{

			/* pass through to wte_pcur() for cursor movement */
			return(w_pcur(&wtes[index], ESC_B));

			break;

		}	/* end case ESC_B */

		case ESC_C:
		{

			/* pass through to wte_pcur() for cursor movement */
			return(w_pcur(&wtes[index], ESC_C));

			break;

		}	/* end case ESC_C */

		case ESC_D:
		{

			/* pass through to wte_pcur() for cursor movement */
			return(w_pcur(&wtes[index], ESC_D));

			break;

		}	/* end case ESC_D */

		case ESC_E:
		{

			/* pass through to wte_pcur() for common command */
			return(w_pcur(&wtes[index], ESC_E));

			break;

		}	/* end case ESC_E */

		case ESC_H:
		{

			/* pass through to wte_pcur() for common command */
			return(w_pcur(&wtes[index], ESC_H));

			break;

		}	/* end case ESC_H */

		case ESC_I:
		{

			/* cursor at first row? */
			if((*pcrow) == 0) /* yes */
			{

				/* blit 1-(last-1) to 2 - last no need to change row # */
				w_blit(&wtes[index], wtes[index].wx, wtes[index].wy,
				((wtes[index].wx+ *pcols * (*ptw)-1)), ((wtes[index].wy+ (*prows -1)*(*pth)-1)),
				wtes[index].wx, (wtes[index].wy + *pth), ((wtes[index].wx+ *pcols * (*ptw)-1)),
				((wtes[index].wy+ (*prows)*(*pth)-1)));

				/* delete first row */
				w_fill(&wtes[index], wtes[index].wx, wtes[index].wy, ((wtes[index].wx+ *pcols * (*ptw)-1)),
				((wtes[index].wy+ (*pth)-1)));

			}	/* end if at first */

			else	/* not at first row */
			{

				srow = (short) ((*pcrow) - 1);
				scol = -1;

				/* move cursor up one */
				w_setc(&wtes[index], &srow, &scol);

			}	/* end if first line else not first line */

			break;

		}	/* end case ESC_I */

		case ESC_Y:
		{

			/* insure row & column in range */
			if(*row < 0 || *row >= *prows)
				return(R_ERR);

			if(*col < 0 || *col >= *pcols)
				return(R_ERR);

			/* set new row and column */
			srow = *row;
			scol = *col;
			w_setc(&wtes[index], &srow, &scol);

			break;

		}	/* end case ESC_Y */

		default:
		{

			/* unknown ESC command, return error */
			return(R_ERR);

			break;

		}	/* end default */

	}	/* end switch(com) */

	return(R_OK);


}	/* end of w_escf */
