/*	Windowed Terminal Emulator
 *	By Erin M. Monaco
 *
 *	Copyright 1994 DataBasement Software
 *	All Rights Reserved
 *
 *	OBJECTIVE:
 *	Provide a library of windowed terminal emulator routines suitable
 *	for displaying/controling a VT-52 type screen within the bounds
 *	of a given window.
 *
 */

#include "W_VT52.H"

/************************************************************************/

/* set up array of WTES stucts */
WTES wtes[WTESIZ];

/*	w_init()
 *
 *	Call after you've opened the window you wish to have terminal emulation
 *	for.  Pass handle of the window	just opened. Sets up default values as
 *	described in W_VT52.DOC file.
 *
 */

int w_init
(
	int windh,						/* opened windows handle */
	short *vdih,					/* vdi handle used */
	short *trows,					/* total number of rows */					
	short *tcols					/* total number of columns */
)

{

	int index;						/* for index value */

	short wi[11] = {1, 1, 1, 1, 1, 1, BLACK, FIS_SOLID, 1, WHITE, 2};
	short wo[57];					/* work_in & work_out arrays */
	short attr[10];				/* text attributes array */
	short d;							/* dummy variable */
	short gh;							/* gems vdi handle */

	int *pwindh;
	short *prows, *pcols, *ptw, *pth;
	short *pvdih;


	/* make sure there isn't a struct already for this window */
	for(index = 0; index < WTESIZ; index++)
	{

		/* check if struct already assigned */
		if(wtes[index].windh == windh)
			return(R_ERR);	/* already init'd so return with error */

	}	/* end looking for duplicate */

	/* reset index */
	index = 0;

	/* find open wtes struct */
	while(wtes[index].windh)
	{
		/* inc index */
		index++;

		/* check index */
		if(index > WTESL)
			return(R_ERR);	/* all WTES structs used, signal error */

	}	/* end while looking for empty WTES struct */

	/* initialize pointers */
	pwindh = &wtes[index].windh;
	pvdih = &wtes[index].vdih;
	prows = &wtes[index].vt.rows;
	pcols = &wtes[index].vt.cols;
	ptw = &wtes[index].vt.tw;
	pth = &wtes[index].vt.th;

	/* get gem's vdi handle */
	gh = (short) (graf_handle(&d, &d, &d, &d));

	/* open virtual workstation with preset defaults and store handle */
	v_opnvwk(&wi[0], &gh, &wo[0]);
	*pvdih = *vdih = gh;

	/* get working coordinates of the window in question */
	if(!(wind_get(windh, WF_WXYWH, &wtes[index].wx, &wtes[index].wy, &wtes[index].ww, &wtes[index].wh)))
	{
		/* release vdi workstation */
		v_clsvwk(gh);

		return(R_ERR);	/* if error, return failure */

	}	/* end if error getting work area */

	/* everythings ok so store window information */
	*pwindh = windh;

	/* get text attributes */
	vqt_attributes(gh, attr);

	/* store text width and height */
	*ptw = attr[8];
	*pth = attr[9];

	/* reset all vdi defaults */

		/* set alignment */
		vst_alignment(gh, 0, 5, &d, &d);

	/* do row & column calculations and store them */

		/* only deal with full rows and columns */
		*trows = *prows = (short) (wtes[index].wh/ (*pth));
		*tcols = *pcols = (short) (wtes[index].ww/ (*ptw));

		/* do quick test */
		if((*prows == 0) || (*pcols ==0))
		{
			/* reset windh and release vdi workstation */
			*pwindh = (short) (0);
			v_clsvwk(gh);

			return(R_ERR);	/* return with error */

		}	/* end if no rows or columns */

	/* handle rest of VT_52 emulators defaults */

		/* reset current row and column */
		wtes[index].vt.crow = 0;
		wtes[index].vt.ccol = 0;

	/* made it this far, return in good health */

	return(R_OK);


}	/* end of w_init */
