/*	Windowed Terminal Emulator
 *	By Erin M. Monaco
 *
 *	Copyright 1994 DataBasement Software
 *	All Rights Reserved
 *
 *	OBJECTIVE:
 *	Provide a library of windowed terminal emulator routines suitable
 *	for displaying/controling a VT-52 type screen within the bounds
 *	of a given window.
 *
 */

#include "W_VT52.H"

/************************************************************************/
/*	w_outs()
 *
 *	Should not be called.  This function is a lower level function of
 *	w_puts().
 *
 */

int w_outs
(
	WTES *wtes,						/* pointer to WTES stuct */
	char *line						/* character to output */
)

{

	int tlen;
	short pxy[4];		/* vdi rectangle */
	short row, col;


	/* line points to one line worth of text which should not exceed */
	/* the last column. */

	/* begin update */
	wind_update(BEG_UPDATE);

	/* hide mouse */
	graf_mouse(M_OFF, NULL);

	/* calculate length of line */
	tlen = strlen(line);

	/* set mode to replace */
	vswr_mode(wtes->vdih, MD_REPLACE);

  /* inline instead of calling wte_fill() should speed this up a bit */
	/* especially when your printing chars 1 at a time */
	/* erase any old text first */
	pxy[0] = (short) (wtes->wx + (wtes->vt.ccol * wtes->vt.tw));
	pxy[1] = (short) (wtes->wy + (wtes->vt.crow * wtes->vt.th));
	pxy[2] = (short) (pxy[0]+ (tlen * wtes->vt.tw) -1);
	pxy[3] = (short) (pxy[1]+ wtes->vt.th -1);

	/* fill rectangle */
	vr_recfl(wtes->vdih, &pxy[0]);

	/* print out line, make sure clipping is off */
	v_gtext(wtes->vdih, pxy[0], pxy[1], line);

	/* show mouse */
	graf_mouse(M_ON, NULL);

	/* end update */
	wind_update(END_UPDATE);

	/* update column */
	col = (short) (wtes->vt.ccol + tlen);
	row = -1;
	w_setc(wtes, &row, &col);

	return(R_OK);


}	/* end of w_outs */
