/*	Windowed Terminal Emulator
 *	By Erin M. Monaco
 *
 *	Copyright 1994 DataBasement Software
 *	All Rights Reserved
 *
 *	OBJECTIVE:
 *	Provide a library of windowed terminal emulator routines suitable
 *	for displaying/controling a VT-52 type screen within the bounds
 *	of a given window.
 *
 */

#include "W_VT52.H"

/************************************************************************/
/*	w_pcur()
 *
 *	Called after initialized. This function allows access to the VT_52
 *	esc+key cursor movement sequences.  This is a lower level function
 *	used by other functions to do simple cursor movements. Should not
 *	be called by user.
 *
 */

int w_pcur
(
	WTES *wtes,						/* pointer to correct WTES structure */
	int com								/* cursor movement esc command */
)

{

	short srow, scol;
	short *ptw, *pth, *prows, *pcols, *pcrow, *pccol;


	ptw = &wtes->vt.tw;
	pth = &wtes->vt.th;
	prows = &wtes->vt.rows;
	pcols = &wtes->vt.cols;
	pcrow = &wtes->vt.crow;
	pccol = &wtes->vt.ccol;


	/* act on specific command */
	switch(com)
	{

		case ESC_A:
		{

			if(*pcrow == 0)
			{

				return(R_ERR);	/* cursor can't go up */

			}

			else
			{

				srow = (short) ((*pcrow) - 1);
				scol = -1;

				/* move cursor up a row */
				w_setc(wtes, &srow, &scol);

			}

			break;

		}	/* end of case ESC_A */

		case ESC_B:
		{

			/* cursor at last row? */
			if((*pcrow) == (*prows - 1))	/* yes */
			{

				/* blit 2nd row - last row to 1st row - last row -1 */
				w_blit(wtes, wtes->wx, (wtes->wy + *pth),
					((wtes->wx+ *pcols * (*ptw)-1)), ((wtes->wy+ (*prows)* (*pth)-1)),
					wtes->wx, wtes->wy, ((wtes->wx+ *pcols * (*ptw)-1)),
					((wtes->wy+ (*prows -1)*(*pth)-1)));

				/* delete last row */
				w_fill(wtes, wtes->wx, (wtes->wy+ (*prows -1)*(*pth)),
				((wtes->wx+ *pcols * (*ptw)-1)), ((wtes->wy+ (*prows)*(*pth)-1)));

			}	/* end if at last row */

			else	/* just inc row number */
			{

				srow = (short) ((*pcrow) + 1);
				scol = -1;

				/* move cursor down a line */
				w_setc(wtes, &srow, &scol);

			}	/* end if at last else not at last row */

			break;

		}	/* end case ESC_B */

		case ESC_C:
		{

			/* cursor at last column? */
			if((*pccol) == ((*pcols) - 1)) /* yes */
			{

				return(R_ERR);	/* already at last column */

			}

			else	/* not at last so inc col number */
			{

				srow = -1;
				scol = (short) ((*pccol) + 1);

				/* move cursor right one */
				w_setc(wtes, &srow, &scol);

			}

			break;

		}	/* end case ESC_C */

		case ESC_D:
		{

			/* cursor already at first column? */
			if((*pccol) == 0) /* yes */
			{

				return(R_ERR);	/* already at first column */

			}

			else	/* not at first so dec col number */
			{

				srow = -1;
				scol = (short) ((*pccol) - 1);

				/* move cursor left one */
				w_setc(wtes, &srow, &scol);

			}

			break;

		}	/* end case ESC_D */

		case ESC_E:
		{

			/* no need to erase cursor as we erase the screen */

			/* erase entire screen */
			w_fill(wtes, wtes->wx, wtes->wy,
			(wtes->wx+wtes->ww-1), (wtes->wy+wtes->wh-1));

			/* reset crow & ccol */
			srow = 0;
			scol = 0;

			/* reset cursor */
			w_setc(wtes, &srow, &scol);

			break;

		}	/* end case ESC_E */

		case ESC_H:
		{

			/* reset crow & ccol */
			*pcrow = 0;
			*pccol = 0;

			break;

		}	/* end case ESC_H */

	}	/* end switch(com) */


	return(R_OK);


}	/* end of w_pcur */
