/*	Windowed Terminal Emulator
 *	By Erin M. Monaco
 *
 *	Copyright 1994 DataBasement Software
 *	All Rights Reserved
 *
 *	OBJECTIVE:
 *	Provide a library of windowed terminal emulator routines suitable
 *	for displaying/controling a VT-52 type screen within the bounds
 *	of a given window.
 *
 */

#include "W_VT52.H"

/************************************************************************/
/*	w_printf()
 *
 *	Called after initialized.  This function performs EXACTLY like ansi C's
 *	printf().  Only difference is that output is confined to the VT_52
 *	rectangle.  Which in the default case is confined to a particular
 *	window.
 *
 */

int w_printf
(
	int windh,						/* windows handle */
	const char *fmt,			/* pointer to format string */
	...										/* variable argument list */
)

{

	va_list	args;

	char	*pbuff;					/* pointer to malloc()'ed buffer */

	int index = 0, ret;


	/* lets malloc our buffer or return on error */
	if((pbuff = malloc(4096)) == NULL)
		return(R_ERR);	/* can't allocate buffer */	

	/* find correct WTES structure or signal error */
	while(wtes[index].windh != windh)
	{

		/* inc index */
		index++;

		/* test */
		if(index > WTESL)
		{

			free(pbuff);		/* free malloc()'ed buffer */
			return(R_ERR);	/* not found, signal error */

		}

	}	/* end while looking for correct WTES struct */	

	/* start variable argument processing */
	va_start(args,fmt);

	/* printf variable arguments to buf */
	vsprintf(pbuff,fmt,args);

	/* end variable argument processing */
	va_end(args);

	ret = (w_puts(&wtes[index], pbuff));

	/* free up malloc()'ed character buffer */
	free(pbuff);

	return(ret);

}	/* end of w_printf */

