/*	Windowed Terminal Emulator
 *	By Erin M. Monaco
 *
 *	Copyright 1994 DataBasement Software
 *	All Rights Reserved
 *
 *	OBJECTIVE:
 *	Provide a library of windowed terminal emulator routines suitable
 *	for displaying/controling a VT-52 type screen within the bounds
 *	of a given window.
 *
 */

#include "W_VT52.H"

/************************************************************************/
/*	w_puts()
 *
 *	Should not be called.  This function is a lower level function of
 *	w_printf().
 *
 */

int w_puts
(
	WTES *wtes,						/* pointer to WTES struct */
	char *buff						/* pointer to arguments buffer */
)

{

	short row, col;		/* row and column */

	char	*plbuff,		/* malloced storage for 1 line of text */
				*dplbuff;		/* duplicate pointer to line buffer */


	/* malloc line buffer return on error */
	if((plbuff = malloc(1024)) == NULL)
		return(R_ERR);	/* not enough memory */

	/* initialize duplicate pointer to line buffer */
	dplbuff = plbuff;

	/* reset line buffer */
	*dplbuff = '\0';

	/* while *buff not null */
	while(*buff)
	{

		switch(*buff)		/* process character */
		{

			case '\n':		/* newline? */
			{

				/* is there text in the line buffer? */
				if(dplbuff != plbuff)		/* yes there is */
				{

					/* print out string at current row & column */
					w_outs(wtes, plbuff);

					/* reset plbuff */
					dplbuff = plbuff;
					*dplbuff = '\0';

				}	/* end if text in line buffer */

				/* action taken regardless of text being in line buffer */
				/* reset column */
				row = -1;
				col = 0;
				w_setc(wtes, &row, &col);

				/* move cursor down to next line */
				w_pcur(wtes, ESC_B);

				break;

			}	/* end case '\n' */

			case '\r':		/* return? */
			{

				/* is there text in the line buffer? */
				if(dplbuff != plbuff)		/* yes there is */
				{

					/* print out string at current row & column */
					w_outs(wtes, plbuff);

					/* reset plbuff */
					dplbuff = plbuff;
					*dplbuff = '\0';

				}	/* end if text in line buffer */

				/* action taken regardless of text being in line buffer */

				/* reset column */
				row = -1;
				col = 0;
				w_setc(wtes, &row, &col);

				/* do NOT move cursor down */

				break;

			}	/* end case '\r' */

			default:			/* all other characters */
			{

				/* at last column? */
				if((wtes->vt.ccol + strlen(plbuff)) == (wtes->vt.cols - 1))	/* yes */
				{

					/* place character in line buffer */
					*(dplbuff++) = *buff;
					*dplbuff = '\0';			/* place null after it */

					/* print line buffer */
					w_outs(wtes, plbuff);

					/* reset column */
					row = -1;
					col = 0;
					w_setc(wtes, &row, &col);

					/* move cursor down a line */
					w_pcur(wtes, ESC_B);

					/* reset line buffer */
					dplbuff = plbuff;
					*dplbuff = '\0';

				}	/* end if at last column */

				else	/* not at last column */
				{

					/* place character in line buffer */
					*(dplbuff++) = *buff;
					*dplbuff = '\0';		/* place null after last character */

				}	/* end if last column else not last column */

				break;

			}	/* end default */

		}	/* end switch(*buff) */

		/* increment buffer pointer */
		buff++;

	}	/* end while(*buff) */

	/* is there stray text in line buffer? */
	if(dplbuff != plbuff)	/* yes there is text in line buffer */
	{

		/* print out line buffer */
		w_outs(wtes, plbuff);

	}	/* end if text in line buffer */

	/* free malloc()'ed buffer */
	free(plbuff);

	return(R_OK);


}	/* end of w_puts */

