/*	Windowed Terminal Emulator
 *	By Erin M. Monaco
 *
 *	Copyright 1994 DataBasement Software
 *	All Rights Reserved
 *
 *	OBJECTIVE:
 *	Provide a library of windowed terminal emulator routines suitable
 *	for displaying/controling a VT-52 type screen within the bounds
 *	of a given window.
 *
 */

#include "W_VT52.H"

/************************************************************************/
/*	w_resize()
 *
 *	Called after initialized.  Recomputes total rows and columns
 *	taking window size and location into account.  Call after a
 *	window move or resizing takes place. Otherwise w_xxxx functions
 *	will break!
 *
 */

int w_resize
(
	int windh,						/* windows handle */
	short *trow,					/* total rows (0 - trow-1) */
	short *tcol						/* total cols (0 - tcol-1) */
)

{

	int index = 0;				/* index value */
	short row = -1, col = -1;

	short *prows, *pcols, *pcrow, *pccol;


	/* find correct WTES structure or signal error */
	while(wtes[index].windh != windh)
	{

		/* inc index */
		index++;

		/* test */
		if(index > WTESL)
			return(R_ERR);	/* not found, signal error */

	}	/* end while looking for correct WTES struct */	

	/* get working coordinates of the window in question */
	if(!(wind_get(windh, WF_WXYWH, &wtes[index].wx, &wtes[index].wy, &wtes[index].ww, &wtes[index].wh)))
		return(R_ERR);	/* if error, return failure */

	/* initialize pointers */
	prows = &wtes[index].vt.rows;
	pcols = &wtes[index].vt.cols;
	pcrow = &wtes[index].vt.crow;
	pccol = &wtes[index].vt.ccol;

	/* do row & column calculations and store them */

		/* only deal with full rows and columns */
		*trow = *prows = (short) (wtes[index].wh/wtes[index].vt.th);
		*tcol = *pcols = (short) (wtes[index].ww/wtes[index].vt.tw);

		/* do quick test */
		if((*prows <= 0) || (*pcols <=0))
			return(R_ERR);	/* return with error */

		/* adjust current and saved row and columns if needed */
		if((*pcrow) >= (*prows))	/* past end? */
		{
			/* yes so adjust */
			row = (short) ((*prows) -1);
		}

		if((*pccol) >= (*pcols))	/* past end? */
		{
			/* yes so adjust */
			col = (short) ((*pcols) -1);
		}

		/* update row & column as necessary */
		w_setc(&wtes[index], &row, &col);

	return(R_OK);


}	/* end of w_resize */ 

